## Spectral Format Table

The spectral format tables are static calibration files that provide some overview information about how each order typically presents itself on the plain of the detector. Useful information includes the minimum and maximum wavelength limits for each order. Here is an example of the XShooter UVB spectral format table contents:

```csv
ORDER,LAMP,WLMINFUL,WLMIN,WLMAX,WLMAXFUL,DISP_MIN,DISP_MAX,LFSR,UFSR
13,QTH,536.57666,544.63275,590.0,603.15594,19.0,2999.0,547.52716,591.32935
14,QTH,499.57135,505.7841,550.3,558.4777,120.0,2999.0,509.7667,547.52716
...
```

